@@ -21,6 +21,7 @@ from napari_lattice.llsz_core import crop_volume_deskew, skimage_decon, pycuda_d
 
 from napari_lattice import config
 
+
 import os
 import numpy as np
 from napari.types import ImageData
@@ -113,7 +114,7 @@ def save_img(vol,
         angle(float, optional) = Deskewing angle in degrees, used to calculate new z
         LLSZWidget(class,optional) = LLSZWidget class
     """              
-    
+
     save_path = save_path.__str__()
     
     #replace any : with _ and remove spaces in case it hasn't been processed/skipped
@@ -362,7 +363,10 @@ def save_img_workflow(vol,
             else:
                 raw_vol = vol[time_point, ch, :, :, :]
             
-            #raw_vol = np.array(raw_vol)
+            #TODO: disable if support for resourc backed dask array is added
+            if type(raw_vol) in [resource_backed_dask_array]:
+                raw_vol = raw_vol.compute() #convert to numpy array as resource backed dask array not su
+            
             #to access current time and channel, create a file config.py in same dir as workflow or in home directory
             #add "channel = 0" and "time=0" in the file and save
             #https://docs.python.org/3/faq/programming.html?highlight=global#how-do-i-share-global-variables-across-modules
@@ -535,10 +539,10 @@ def save_img_workflow(vol,
 
     return
 
-#class for initiliazing lattice data and setting metadata
+#class for initializing lattice data and setting metadata
 #TODO: handle scenes
 class LatticeData():
-    def __init__(self,img,angle,skew,dx,dy,dz,channel_dimension) -> None:
+    def __init__(self,img,angle,skew,dx,dy,dz,last_dimension) -> None:
         self.angle = angle
         self.skew = skew
         #if image layer
@@ -557,14 +561,67 @@ class LatticeData():
                     img_data_aics = img.metadata['aicsimage']
                     self.data = img_data_aics.dask_data
                     self.dims = img_data_aics.dims
-                    self.time = img_data_aics.dims.T
-                    self.channels = img_data_aics.dims.C
+                    #if aicsimageio tiffreader assigns last dim as time when it should be channel, user can override this
+                    if last_dimension:
+                        if len(img.data.shape)==4:
+                            if last_dimension.lower() == "channel":
+                                self.channels = img.data.shape[0]
+                                self.time=0
+                            elif last_dimension.lower() == "time":
+                                self.time = img.data.shape[0]
+                                self.channels=0
+                        elif len(img.data.shape)==5:
+                            if last_dimension.lower() == "channel":
+                                self.channels = img.data.shape[0]
+                                self.time = img.data.shape[1]
+                            elif last_dimension.lower() == "time":
+                                self.time = img.data.shape[0]
+                                self.channels = img.data.shape[1]                       
+                    else:
+                        self.time = img_data_aics.dims.T
+                        self.channels = img_data_aics.dims.C
                 else: 
                     #if no aicsimageio key in metadata
                     #get the data and convert it into an aicsimage object
                     img_data_aics = aicsimageio.AICSImage(img.data)
                     self.data = img_data_aics.dask_data
-                
+                    #if user has specified ch
+                    if last_dimension:
+                        if len(img.data.shape)==4:
+                            if last_dimension.lower() == "channel":
+                                self.channels = img.data.shape[0]
+                                self.time=0
+                            elif last_dimension.lower() == "time":
+                                self.time = img.data.shape[0]
+                                self.channels=0
+                        elif len(img.data.shape)==5:
+                            if last_dimension.lower() == "channel":
+                                self.channels = img.data.shape[0]
+                                self.time = img.data.shape[1]
+                            elif last_dimension.lower() == "time":
+                                self.time = img.data.shape[0]
+                                self.channels = img.data.shape[1]
+                    else:
+                        if last_dimension:
+                            if len(img.data.shape)==4:
+                                if last_dimension.lower() == "channel":
+                                    self.channels = img.data.shape[0]
+                                    self.time=0
+                                elif last_dimension.lower() == "time":
+                                    self.time = img.data.shape[0]
+                                    self.channels=0
+                            elif len(img.data.shape)==5:
+                                if last_dimension.lower() == "channel":
+                                    self.channels = img.data.shape[0]
+                                    self.time = img.data.shape[1]
+                                elif last_dimension.lower() == "time":
+                                    self.time = img.data.shape[0]
+                                    self.channels = img.data.shape[1]
+                        else:
+                            
+                            self.time = img.data.shape[0]
+                            self.channels = img.data.shape[1]
+                            
                 #read metadata for pixel sizes
                 if None in img_data_aics.physical_pixel_sizes or img_data_aics.physical_pixel_sizes== False:
                     self.dx = dx
@@ -572,12 +629,16 @@ class LatticeData():
                     self.dz = dz
                 else:
                     self.dz,self.dy,self.dx = img.data.physical_pixel_sizes
-                #if not channel_dimension:
+                #if not last_dimension:
                 #if xarray, access data using .data method
                     #if type(img.data) in [xarray.core.dataarray.DataArray,np.ndarray]:
                         #img = img.data
                 #img = dask_expand_dims(img,axis=1) ##if no channel dimension specified, then expand axis at index 1
             #if no path returned by source.path, get image name with colon and spaces removed
+            #if last axes of "aicsimage data" shape is not equal to time, then swap channel and time
+            if self.data.shape[0]!= self.time or self.data.shape[1]!= self.channels:
+                self.data = np.swapaxes(self.data,0,1)
+            
             if img.source.path is None:
                 self.save_name = img.name.replace(":","").strip() #remove colon (:) and any leading spaces
                 self.save_name = '_'.join(self.save_name.split()) #replace any group of spaces with "_"
@@ -621,7 +682,8 @@ class LatticeData():
                 
         #process the file to get shape of final deskewed image
         self.deskew_vol_shape = get_deskewed_shape(self.data, self.angle,self.dx,self.dy,self.dz)
-
+        print(f"Channels: {self.channels}, Time: {self.time}")
+        print("If channel and time need to be swapped, you can enforce this by choosing 'Last dimension is channel' when initialising the plugin")
         pass 
 
     def get_angle(self):
